==> haskell-skein-1.0.9.4-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
key: skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
license: BSD3
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
abi: e880e85c53de2bd837d2b1155fcfd522
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/skein-1.0.9.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
includes:
    skein.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skein-1.0.9.4-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-KramXVCnAKDGRXgYFhJaGE
key: skein-1.0.9.4-KramXVCnAKDGRXgYFhJaGE
license: BSD3
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
abi: da2dee6c0fffe5eb89005c70f94682ea
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/skein-1.0.9.4
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-KramXVCnAKDGRXgYFhJaGE
includes:
    skein.h
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    cereal-0.5.4.0-KtX8p6mYm6IKYn6d7ncsjw
    crypto-api-0.13.2-9bOk64nijR6HE0oEbExciE
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
